@@ -19,7 +19,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
 #include "encodercda.h"
@@ -42,7 +42,10 @@ const char * EncoderCda::mimeType() const {
 // Remove this by calculating CD_FRAMESIZE_RAW from the frames
 extern "C"
 {
+  //cdda_interface.h in cdparanoia 10.2 has a member called 'private' which the C++ compiler doesn't like
+  #define private _private
   #include <cdda_interface.h>
+  #undef private
 }
 
 inline int16_t swap16 (int16_t i)
@@ -59,9 +62,9 @@ long EncoderCda::read(int16_t * buf, int frames){
     for (int i=0; i < 2 * frames; i++)
        buf[i] = swap16 (buf[i]);
   char * cbuf = reinterpret_cast<char *>(buf);
-  output.setRawData(cbuf, CD_FRAMESIZE_RAW);
+  output = QByteArray::fromRawData(cbuf, CD_FRAMESIZE_RAW);
   ioslave->data(output);
-  output.resetRawData(cbuf, CD_FRAMESIZE_RAW);
+  output.clear();
   return CD_FRAMESIZE_RAW;
 }
 
