@@ -48,21 +48,42 @@ KMixApp::~KMixApp()
 int
 KMixApp::newInstance()
 {
+        // There are 3 cases for a new instance
+
 	//kDebug(67100) <<  "KMixApp::newInstance() isRestored()=" << isRestored() << "_keepVisibility=" << _keepVisibility;
-	if ( m_kmix )
+	static bool first = true;
+	if ( !first )
 	{	// There already exists an instance/window
+ 
+                /* !!! @bug : _keepVisibilty has the wrong value here.
+                    It is supposed to have the value set by the command line
+                    arg, and the keepVisibilty() method.
+                    All looks fine, BUT(!!!) THIS code is NEVER entered in
+                    the just started process.
+                    KDE IPC (DBUS) has instead notified the already running
+                    KMix process, about a newInstance(). So _keepVisibilty
+                    has always the value of the first started KMix process.
+                    This is a bug in KMix and  must be fixed.
+                    cesken, 2008-11-01
+                 */
+                 
 		kDebug(67100) <<  "KMixApp::newInstance() Instance exists";
 
 		if ( ! _keepVisibility && !isSessionRestored() ) {
-			//kDebug(67100) <<  "KMixApp::newInstance() _keepVisibility=false";
-			// Default case: If KMix is running and the *USER*
+			kDebug(67100) <<  "KMixApp::newInstance() SHOW WINDOW (_keepVisibility=" << _keepVisibility << ", isSessionRestored=" << isSessionRestored();
+			// CASE 1: If KMix is running AND the *USER*
                         // starts it again, the KMix main window will be shown.
 			// If KMix is restored by SM or the --keepvisibilty is used, KMix will NOT
 			// explicitly be shown.
-			m_kmix->show();
+			if ( !m_kmix ) {
+				m_kmix->show();
+			} else {
+				kWarning(67100) << "KMixApp::newInstance() Window has not finished constructing yet so ignoring the show() request.";
+			}
 		}
 		else {
-			//kDebug(67100) <<  "KMixApp::newInstance() _keepVisibility=true || isRestored()=true";
+                        // CASE 2: If KMix is running, AND  ( session gets restored OR keepvisibilty command line switch )
+			kDebug(67100) <<  "KMixApp::newInstance() REGULAR_START _keepVisibility=" << _keepVisibility;
 			// Special case: Command line arg --keepVisibility was used:
 			// We don't want to change the visibiliy, thus we don't call show() here.
 			//
@@ -74,8 +95,14 @@ KMixApp::newInstance()
 	}
 	else
 	{
-		//kDebug(67100) <<  "KMixApp::newInstance() !m_kmix";
-		m_kmix = new KMixWindow;
+                // CASE 3: KMix was not running yet => instanciate a new one
+		//kDebug(67100) <<  "KMixApp::newInstance() Instanciate: _keepVisibility=" << _keepVisibility ;
+		first = false;	// NB See https://qa.mandriva.com/show_bug.cgi?id=56893#c3
+				// It is important to track this via a separate variable and not
+				// based on m_kmix to handle this race condition.
+				// Specific protection for the activation-prior-to-full-construction
+				// case exists above in the 'already running case'
+		m_kmix = new KMixWindow(_keepVisibility);
 		//connect(this, SIGNAL(stopUpdatesOnVisibility()), m_kmix, SLOT(stopVisibilityUpdates()));
 		if ( isSessionRestored() && KMainWindow::canBeRestored(0) )
 		{
@@ -86,9 +113,7 @@ KMixApp::newInstance()
 	return 0;
 }
 
-
 void KMixApp::keepVisibility(bool val_keepVisibility) {
-   //kDebug(67100) <<  "KMixApp::keepVisibility()";
    _keepVisibility = val_keepVisibility;
 }
 
