@@ -106,7 +106,8 @@ int Mixer_ALSA::identify( snd_mixer_selem_id_t *sid )
    if (name.contains("mic"        , Qt::CaseInsensitive)) return MixDevice::MICROPHONE;
    if (name.contains("lfe"        , Qt::CaseInsensitive)) return MixDevice::SURROUND_LFE;
    if (name.contains("monitor"    , Qt::CaseInsensitive)) return MixDevice::RECMONITOR;
-   if (name.contains("3d"         , Qt::CaseInsensitive)) return MixDevice::SURROUND;  // Should be probably some own icon
+   if (name.contains("3d"         , Qt::CaseInsensitive)) return MixDevice::SURROUND;
+   if (name.contains("side"       , Qt::CaseInsensitive)) return MixDevice::SURROUND_BACK;
 
    return MixDevice::EXTERNAL;
 }
@@ -420,10 +421,10 @@ Volume* Mixer_ALSA::addVolume(snd_mixer_elem_t *elem, bool capture)
     }
 
 
-    // Chek if this control has at least one volume control
+    // Check if this control has at least one volume control
     bool hasVolume = (chn != Volume::MNONE);
 
-    // Chek if a appropriate switch is present (appropriate means, based o nthe "capture" parameer)
+    // Check if a appropriate switch is present (appropriate means, based o nthe "capture" parameer)
     bool hasCommonSwitch = snd_mixer_selem_has_common_switch ( elem );
 
     bool hasSwitch = hasCommonSwitch |
@@ -732,6 +733,7 @@ Mixer_ALSA::readVolumeFromHW( const QString& id, MixDevice *md )
     } // has playback volume
 
     // --- playback switch
+    // TODO: What about has_common_switch()
     if ( snd_mixer_selem_has_playback_switch( elem ) )
     {
         snd_mixer_selem_get_playback_switch( elem, SND_MIXER_SCHN_FRONT_LEFT, &elem_sw );
@@ -765,6 +767,7 @@ Mixer_ALSA::readVolumeFromHW( const QString& id, MixDevice *md )
     } // has capture volume
 
     // --- capture switch
+    // TODO: What about has_common_switch()
     if ( snd_mixer_selem_has_capture_switch( elem ) )
     {
         snd_mixer_selem_get_capture_switch( elem, SND_MIXER_SCHN_FRONT_LEFT, &elem_sw );
@@ -843,7 +846,7 @@ Mixer_ALSA::writeVolumeToHW( const QString& id, MixDevice *md )
                    default: kDebug() << "FATAL: Unknown channel type for capture << " << i << " ... please report this";  break;
               }
               if ( ret != 0 ) kDebug(67100) << "writeVolumeToHW(" << devnum << ") [set_capture_volume] failed, errno=" << ret;
-              if (id== "Master:0" || id== "PCM:0" ) { kDebug() << "volumecapture control=" << id << ", chid=" << i << ", vol=" << volumeCapture[i]; }
+              //if (id== "Master:0" || id== "PCM:0" ) { kDebug() << "volumecapture control=" << id << ", chid=" << i << ", vol=" << volumeCapture[i]; }
           }
        }
     } // has capture volume
